==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Image/Gui/Resources/translations/Image_zh-TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh-TW" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+101"/>
      <source>Image</source>
      <translation>影像</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>建立影像平面</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>於3D空間建立平面影像</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation type="unfinished">create a planar image in the 3D space</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-50"/>
      <source>Image</source>
      <translation>影像</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>開啟</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>打開影像檢視</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+333"/>
      <location filename="../../OpenGLImageBox.cpp" line="+385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>未定義色彩供圖片使用</translation>
    </message>
    <message>
      <location line="-1"/>
      <location filename="../../OpenGLImageBox.cpp" line="-1"/>
      <source>Image pixel format</source>
      <translation>影像像素格式</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation type="unfinished">Choose orientation</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation>影像平面</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation type="unfinished">XY-Plane</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation type="unfinished">XZ-Plane</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation type="unfinished">YZ-Plane</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation type="unfinished">Reverse direction</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation type="unfinished">Offset:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+107"/>
      <source>&amp;Fit image</source>
      <translation>符合圖片尺寸(&amp;F)</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>延伸影像符合頁面大小</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>&amp;1:1 比例</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>在1:1的比例顯示影像</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>原始顏色</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation type="unfinished">Display the image with its original color(s)</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation type="unfinished">&amp;Brightened color</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation type="unfinished">Display the image with brightened color(s)</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>標準</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Ready...</source>
      <translation>準備...</translation>
    </message>
    <message>
      <location line="+390"/>
      <source>grey</source>
      <translation>灰色</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>縮放</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>外部影像</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>影像檢視器</translation>
    </message>
    <message>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>影像（*.PNG *.JPG *.XPM *.BMP）</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+20"/>
      <location line="+47"/>
      <source>Choose an image file to open</source>
      <translation>選擇要打開的影像檔</translation>
    </message>
    <message>
      <location line="-54"/>
      <location line="+47"/>
      <source>Images</source>
      <translation>影像</translation>
    </message>
    <message>
      <location line="-42"/>
      <location line="+47"/>
      <source>All files</source>
      <translation>所有檔案</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error opening image</source>
      <translation type="unfinished">Error opening image</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the chosen image</source>
      <translation type="unfinished">Could not load the chosen image</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>開啟影像錯誤</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>無法載入選擇影像</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>影像</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Image/Gui/Resources/translations/Image_zh-TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh-TW" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+101"/>
      <source>Image</source>
      <translation>影像</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>建立影像平面</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>於3D空間建立平面影像</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation type="unfinished">create a planar image in the 3D space</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-50"/>
      <source>Image</source>
      <translation>影像</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>開啟</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>打開影像檢視</translation>
    </message>
  </context>
  <context>
    <name>CmdImageScaling</name>
    <message>
      <location line="+120"/>
      <source>Image</source>
      <translation>影像</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Scale...</source>
      <translation type="unfinished">Scale...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Image Scaling</source>
      <translation type="unfinished">Image Scaling</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+333"/>
      <location filename="../../OpenGLImageBox.cpp" line="+385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>未定義色彩供圖片使用</translation>
    </message>
    <message>
      <location line="-1"/>
      <location filename="../../OpenGLImageBox.cpp" line="-1"/>
      <source>Image pixel format</source>
      <translation>影像像素格式</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation type="unfinished">Choose orientation</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation>影像平面</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation type="unfinished">XY-Plane</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation type="unfinished">XZ-Plane</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation type="unfinished">YZ-Plane</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation type="unfinished">Reverse direction</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation type="unfinished">Offset:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+107"/>
      <source>&amp;Fit image</source>
      <translation>符合圖片尺寸(&amp;F)</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>延伸影像符合頁面大小</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>&amp;1:1 比例</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>在1:1的比例顯示影像</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>原始顏色</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation type="unfinished">Display the image with its original color(s)</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation type="unfinished">&amp;Brightened color</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation type="unfinished">Display the image with brightened color(s)</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>標準</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Ready...</source>
      <translation>準備...</translation>
    </message>
    <message>
      <location line="+390"/>
      <source>grey</source>
      <translation>灰色</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>縮放</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>外部影像</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>影像檢視器</translation>
    </message>
    <message>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>影像（*.PNG *.JPG *.XPM *.BMP）</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-102"/>
      <location line="+47"/>
      <source>Choose an image file to open</source>
      <translation>選擇要打開的影像檔</translation>
    </message>
    <message>
      <location line="-54"/>
      <location line="+47"/>
      <source>Images</source>
      <translation>影像</translation>
    </message>
    <message>
      <location line="-42"/>
      <location line="+47"/>
      <source>All files</source>
      <translation>所有檔案</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error opening image</source>
      <translation type="unfinished">Error opening image</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the chosen image</source>
      <translation type="unfinished">Could not load the chosen image</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>開啟影像錯誤</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>無法載入選擇影像</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>影像</translation>
    </message>
  </context>
</TS>
